TIME = "/time"
CREATE_API_KEY = "/create-api-key"
GET_API_KEYS = "/get-api-keys"
DELETE_API_KEY = "/delete-api-key"
DERIVE_API_KEY = "/derive-api-key"
TRADES = "/trades"
GET_ORDER_BOOK = "/book"
GET_ORDER = "/order/"
ORDERS = "/orders"
POST_ORDER = "/order"
CANCEL = "/order"
CANCEL_ORDERS = "/orders"
CANCEL_ALL = "/cancel-all"
CANCEL_MARKET_ORDERS = "/cancel-market-orders"
MID_POINT = "/midpoint"
PRICE = "/price"
GET_LAST_TRADE_PRICE = "/last-trade-price"
GET_TRADE_NOTIFICATIONS = "/trade-notifications"
DROP_TRADE_NOTIFICATIONS = "/drop-trade-notifications"
